#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void _aB_F__0__G__1___TwoPRep_D__0__P__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack);
#ifdef __cplusplus
};
#endif
